import ipaddress
import sys
from io import StringIO

import pytest

from circlecitest.main import get_ip, print_result


@pytest.mark.asyncio
async def test_get_ip():
    result = await get_ip()
    assert isinstance(result, str)
    assert isinstance(ipaddress.ip_address(result), ipaddress.IPv4Address)


def test_print_result():
    captured_output = StringIO()
    sys.stdout = captured_output

    value = 'some string'

    result = print_result(value)
    assert result is None
    assert f'Your IP is {value}\n' == captured_output.getvalue()



import asyncio

import aiohttp


async def get_ip() -> str:
    url = 'https://api.ipify.org?format=json'
    async with aiohttp.ClientSession() as session:
        async with session.get(url) as response:
            response_json = await response.json()
            return response_json['ip']


def print_result(ip: str):
    print(f'Your IP is {ip}')


async def main():
    print_result(await get_ip())


if __name__ == '__main__':
    asyncio.run(main())



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['circlecitest']

package_data = \
{'': ['*'], 'circlecitest': ['tests/*']}

install_requires = \
['aiohttp>=3.5,<4.0']

setup_kwargs = {
    'name': 'circlecitest',
    'version': '0.1.0',
    'description': 'testing pypi deploy',
    'long_description': None,
    'author': 'ape364',
    'author_email': 'ape364@gmail.com',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
